/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-03-18 10:21:49
 * @LastEditTime: 2023-06-19 14:14:54
 * @LastEditors: lihl
 * @Version: 1.0.0
 * @Description: 调解大数据
 */
import React, { useState, useEffect, useMemo, useRef } from 'react';
import * as $$ from '../../../utils/utility';
import { useLocation, useNavigate, useSearchParams, useOutletContext } from 'react-router-dom';
import Page from '../../../components/Page';
import {
  Col, Form, Row, TreeSelect, Button, DatePicker, Space, Radio, Typography,
  Card, Divider, Alert, Table
} from 'antd';
import './index.less';
import { Chart } from '@antv/g2';
import { Pie, measureTextWidth, Progress } from '@ant-design/plots';
import mediateBigData_1 from '../../../assets/images/mediateBigData_1.png';
import mediateBigData_2 from '../../../assets/images/mediateBigData_2.png';
import mediateBigData_3 from '../../../assets/images/mediateBigData_3.png';
import mediateBigData_4 from '../../../assets/images/mediateBigData_4.png';
import mediateBigData_5 from '../../../assets/images/mediateBigData_5.png';
import mediateBigData_6 from '../../../assets/images/mediateBigData_6.png';
import mediateBigData_7 from '../../../assets/images/mediateBigData_7.png';
import mediateBigData_8 from '../../../assets/images/mediateBigData_8.png';


// 获取所有数据
function getAllDataApi (submitData) {
  return $$.ax.request({ url: 'caseInfo/getMediBigData', type: 'get', data: submitData, service: 'mediate' });
}

// 获取折线图数据
function getChartDataApi (submitData) {
  return $$.ax.request({ url: 'caseInfo/countOneYear', type: 'get', data: submitData, service: 'mediate' });
}

const resTest = {
  "code": 0,
  "msg": "请求成功",
  "data": {
    "workTopList": [
      {
        "收案数": 6845,
        "name": "白云区人民法院"
      },
      {
        "收案数": 736,
        "name": "白云区信访局"
      },
      {
        "收案数": 217,
        "name": "白云区文化广电旅游体育局"
      },
      {
        "收案数": 194,
        "name": "白云区龙归街道办"
      },
      {
        "收案数": 192,
        "name": "白云区棠景街道办"
      },
      {
        "收案数": 187,
        "name": "白云区新市街道办"
      },
      {
        "收案数": 185,
        "name": "白云区石门街道办"
      },
      {
        "收案数": 172,
        "name": "白云区同德街道办"
      },
      {
        "收案数": 145,
        "name": "白云区均禾街道办"
      },
      {
        "收案数": 101,
        "name": "白云区鹤龙街道办"
      }
    ],
    "allCanal": {
      "小程序调解中": 4,
      "网格联动调解成功": 0,
      "小程序调解成功": 131,
      "机构登记调解不成功": 1584,
      "小程序待调解": 4,
      "网格联动调解不成功": 0,
      "调解不成功数": 1629,
      "网格系统转入调解成功率": 0,
      "小程序撤回调解": 0,
      "机构登记调解中": 6,
      "已调解总数": 12237,
      "转诉讼": 6,
      "市人民调解系统": 0,
      "总数": 12524,
      "市人民调解系统调解成功": 0,
      "市人民调解系统调解中": 0,
      "小程序": 210,
      "网格联动调解中": 0,
      "机构登记案件导入": 1131,
      "市人民调解系统调解不成功": 0,
      "机构登记": 12273,
      "网格联动": 0,
      "机构登记调解成功": 10444,
      "小程序不予受理": 1,
      "总调解成功率": 86.69,
      "调解成功数": 10608,
      "已结束": 12333,
      "小程序调解不成功": 45,
      "调解中": 6,
      "小程序调解成功率": 74.43,
      "未开始": 134,
      "机构登记调解成功率": 86.83,
      "机构登记个案登记": 11142,
      "人民调解系统转入调解成功率": 0
    },
    "realTimeDynamicList": [
      {
        "task_node_name": "指派调解员",
        "case_title": "马少华和曹灼南的邻里纠纷案件",
        "mediator": "刘伟国",
        "finish_time": "2023-12-19T16:00:00.000+0000",
        "mediate_unit_name": "良田村人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "马少华和曹灼南的邻里纠纷案件",
        "mediator": "刘伟国",
        "finish_time": "2023-12-19T16:00:00.000+0000",
        "mediate_unit_name": "良田村人民调解委员会"
      },
      {
        "task_node_name": "结果确认",
        "case_title": "马少华和曹灼南的邻里纠纷案件",
        "mediator": "刘伟国",
        "finish_time": "2023-12-19T16:00:00.000+0000",
        "mediate_unit_name": "良田村人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "王文豪和张三的邻里纠纷案件",
        "mediator": "冯凯",
        "finish_time": "2023-06-05T09:51:25.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "王文豪和张三的邻里纠纷案件",
        "mediator": "冯凯",
        "finish_time": "2023-06-05T09:45:56.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "王文豪和张三的邻里纠纷案件",
        "mediator": "冯凯",
        "finish_time": "2023-06-05T08:01:28.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "王文豪和张三的邻里纠纷案件",
        "mediator": "冯凯",
        "finish_time": "2023-06-05T07:59:46.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "李泳江和陈雄的邻里纠纷案件",
        "mediator": "谭桂华",
        "finish_time": "2023-05-31T06:10:18.000+0000",
        "mediate_unit_name": "白云区白云湖街道办"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "李泳江和陈雄的邻里纠纷案件",
        "mediator": "谭桂华",
        "finish_time": "2023-05-31T06:08:51.000+0000",
        "mediate_unit_name": "白云区白云湖街道办"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "李明等和广东凯厦建筑工程有限公司等的合同纠纷案件",
        "mediator": "钟振波",
        "finish_time": "2023-05-30T04:00:00.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "结果确认",
        "case_title": "李明等和广东凯厦建筑工程有限公司等的合同纠纷案件",
        "mediator": "钟振波",
        "finish_time": "2023-05-30T04:00:00.000+0000",
        "mediate_unit_name": "白云区江高镇街道办"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "冯先生和吴先生的邻里纠纷案件",
        "mediator": "梁国树",
        "finish_time": "2023-05-29T09:28:22.000+0000",
        "mediate_unit_name": "石榴桥社区人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "冯先生和吴先生的邻里纠纷案件",
        "mediator": "梁国树",
        "finish_time": "2023-05-29T09:27:39.000+0000",
        "mediate_unit_name": "石榴桥社区人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "冯先生和吴先生的邻里纠纷案件",
        "mediator": "梁国树",
        "finish_time": "2023-05-29T09:25:16.000+0000",
        "mediate_unit_name": "石榴桥社区人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "黄小姐和刘嘉怡的合同纠纷案件",
        "mediator": "张志聪",
        "finish_time": "2023-05-29T08:53:18.000+0000",
        "mediate_unit_name": "新村社区人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "庞芳妹和钟秋兰的邻里纠纷案件",
        "mediator": "黎铭生",
        "finish_time": "2023-05-29T08:48:43.000+0000",
        "mediate_unit_name": "长湴社区人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "黄小姐和刘嘉怡的合同纠纷案件",
        "mediator": "张志聪",
        "finish_time": "2023-05-29T08:46:42.000+0000",
        "mediate_unit_name": "新村社区人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "庞芳妹和钟秋兰的邻里纠纷案件",
        "mediator": "黎铭生",
        "finish_time": "2023-05-29T08:44:14.000+0000",
        "mediate_unit_name": "长湴社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "颜鸿武和候金凤的家庭婚姻纠纷案件",
        "mediator": "梁文瀚",
        "finish_time": "2023-05-29T08:43:32.000+0000",
        "mediate_unit_name": "金麟社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "余家宁和方奕媛的物业管理纠纷案件",
        "mediator": "梁文瀚",
        "finish_time": "2023-05-29T08:43:24.000+0000",
        "mediate_unit_name": "金麟社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "谭德锋和任权的其他纠纷案件",
        "mediator": "梁文瀚",
        "finish_time": "2023-05-29T08:43:11.000+0000",
        "mediate_unit_name": "金麟社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "萧浩炜和萧浩强的家庭婚姻纠纷案件",
        "mediator": "萧锐佳",
        "finish_time": "2023-05-29T08:41:27.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "萧浩炜和萧浩强的家庭婚姻纠纷案件",
        "mediator": "萧锐佳",
        "finish_time": "2023-05-29T08:40:08.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "陈玉媚和杨丽群的邻里纠纷案件",
        "mediator": "黎铭生",
        "finish_time": "2023-05-29T08:36:52.000+0000",
        "mediate_unit_name": "长湴社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "李羿源和何丽崧的环境污染纠纷案件",
        "mediator": "李丽华",
        "finish_time": "2023-05-29T08:33:36.000+0000",
        "mediate_unit_name": "马务社区人民调解委员会"
      },
      {
        "task_node_name": "结案归档",
        "case_title": "冯张莲和萧就胜的邻里纠纷案件",
        "mediator": "萧锦坚",
        "finish_time": "2023-05-29T08:32:20.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "萧浩炜和萧浩强的家庭婚姻纠纷案件",
        "mediator": "萧锐佳",
        "finish_time": "2023-05-29T08:27:20.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "李羿源和何丽崧的环境污染纠纷案件",
        "mediator": "李丽华",
        "finish_time": "2023-05-29T08:27:02.000+0000",
        "mediate_unit_name": "马务社区人民调解委员会"
      },
      {
        "task_node_name": "纠纷调解",
        "case_title": "冯张莲和萧就胜的邻里纠纷案件",
        "mediator": "萧锦坚",
        "finish_time": "2023-05-29T08:22:30.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      },
      {
        "task_node_name": "指派调解员",
        "case_title": "冯张莲和萧就胜的邻里纠纷案件",
        "mediator": "萧锦坚",
        "finish_time": "2023-05-29T08:18:05.000+0000",
        "mediate_unit_name": "寮采村人民调解委员会"
      }
    ],
    "thisMonthIncrease": {
      "去年调解结束": 0,
      "本月调解成功": 0,
      "上个月调解成功": 0,
      "本月调解成功同比": 0,
      "本月调解结束": 0,
      "去年新增": 0,
      "去年调解成功": 0,
      "本月调解成功率": 0,
      "上个月新增": 0,
      "本月调解成功环比": 0,
      "上个月调解结束": 0,
      "本月新增": 1
    },
    "trendAnalysisList": [
      {
        "MONTH": "2022-12",
        "小程序登记调解失败": 6,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 182,
        "小程序登记调解成功": 4,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 281,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 14,
        "网格联动系统登记调解成功": 0,
        "机构登记": 468
      },
      {
        "MONTH": "2023-01",
        "小程序登记调解失败": 2,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 138,
        "小程序登记调解成功": 3,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 288,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 5,
        "网格联动系统登记调解成功": 0,
        "机构登记": 426
      },
      {
        "MONTH": "2023-02",
        "小程序登记调解失败": 2,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 214,
        "小程序登记调解成功": 4,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 101,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 7,
        "网格联动系统登记调解成功": 0,
        "机构登记": 316
      },
      {
        "MONTH": "2023-03",
        "小程序登记调解失败": 0,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 311,
        "小程序登记调解成功": 2,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 62,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 6,
        "网格联动系统登记调解成功": 0,
        "机构登记": 393
      },
      {
        "MONTH": "2023-04",
        "小程序登记调解失败": 3,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 767,
        "小程序登记调解成功": 7,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 15,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 22,
        "网格联动系统登记调解成功": 0,
        "机构登记": 921
      },
      {
        "MONTH": "2023-05",
        "小程序登记调解失败": 1,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 828,
        "小程序登记调解成功": 1,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 6,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 13,
        "网格联动系统登记调解成功": 0,
        "机构登记": 895
      },
      {
        "MONTH": "2023-06",
        "小程序登记调解失败": 0,
        "市人民调解系统登记调解成功": 0,
        "网格联动": 0,
        "机构登记调解成功": 0,
        "小程序登记调解成功": 0,
        "市人民调解系统登记调解失败": 0,
        "机构登记调解失败": 0,
        "市人民调解系统": 0,
        "网格联动系统登记调解失败": 0,
        "小程序": 0,
        "网格联动系统登记调解成功": 0,
        "机构登记": 1
      }
    ],
    "reportStatisticsList": [
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6845,
        "name": "白云区人民法院",
        "调解成功数": 6457,
        "线上转诉": 4,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 385
      },
      {
        "调解中": 0,
        "小程序数": 5,
        "录入总数": 736,
        "name": "白云区信访局",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 718
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 217,
        "name": "白云区文化广电旅游体育局",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 217
      },
      {
        "调解中": 0,
        "小程序数": 4,
        "录入总数": 194,
        "name": "白云区龙归街道办",
        "调解成功数": 181,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 13
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 192,
        "name": "白云区棠景街道办",
        "调解成功数": 166,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 4
      },
      {
        "调解中": 0,
        "小程序数": 36,
        "录入总数": 187,
        "name": "白云区新市街道办",
        "调解成功数": 122,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 20,
        "录入总数": 185,
        "name": "白云区石门街道办",
        "调解成功数": 163,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 172,
        "name": "白云区同德街道办",
        "调解成功数": 166,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 2,
        "录入总数": 145,
        "name": "白云区均禾街道办",
        "调解成功数": 143,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 5,
        "录入总数": 101,
        "name": "白云区鹤龙街道办",
        "调解成功数": 74,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 27
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 92,
        "name": "白云区金沙街道办",
        "调解成功数": 87,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 4
      },
      {
        "调解中": 0,
        "小程序数": 13,
        "录入总数": 79,
        "name": "白云区太和镇街道办",
        "调解成功数": 61,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 9
      },
      {
        "调解中": 0,
        "小程序数": 5,
        "录入总数": 72,
        "name": "白云区嘉禾街道办",
        "调解成功数": 70,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 4,
        "录入总数": 64,
        "name": "白云区三元里街道办",
        "调解成功数": 57,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 7
      },
      {
        "调解中": 0,
        "小程序数": 4,
        "录入总数": 61,
        "name": "白云区松洲街道办",
        "调解成功数": 61,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 58,
        "name": "白云区大源街道办",
        "调解成功数": 56,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 23,
        "录入总数": 57,
        "name": "白云区云城街道办",
        "调解成功数": 52,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 56,
        "name": "白云区京溪街道办",
        "调解成功数": 56,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 3,
        "小程序数": 7,
        "录入总数": 55,
        "name": "演示街道办",
        "调解成功数": 30,
        "线上转诉": 0,
        "司法确认数": 1,
        "本月新增": 0,
        "调解失败数": 10
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 51,
        "name": "大源村人民调解委员会",
        "调解成功数": 49,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 50,
        "name": "望南社区人民调解委员会",
        "调解成功数": 30,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 20
      },
      {
        "调解中": 0,
        "小程序数": 14,
        "录入总数": 50,
        "name": "白云区永平街道办",
        "调解成功数": 45,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 10,
        "录入总数": 45,
        "name": "白云区人和镇街道办",
        "调解成功数": 35,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 10
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 45,
        "name": "凰岗社区人民调解委员会",
        "调解成功数": 45,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 5,
        "录入总数": 43,
        "name": "白云区白云湖街道办",
        "调解成功数": 38,
        "线上转诉": 0,
        "司法确认数": 1,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 4,
        "录入总数": 40,
        "name": "白云区黄石街道办",
        "调解成功数": 36,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 3
      },
      {
        "调解中": 0,
        "小程序数": 3,
        "录入总数": 39,
        "name": "白云区同和街道办",
        "调解成功数": 35,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 3
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 38,
        "name": "陈田社区人民调解委员会",
        "调解成功数": 38,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 35,
        "name": "太和社区人民调解委员会",
        "调解成功数": 31,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 3
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 34,
        "name": "新村社区人民调解委员会",
        "调解成功数": 34,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 33,
        "name": "磨溪社区人民调解委员会",
        "调解成功数": 33,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 8,
        "录入总数": 33,
        "name": "白云区江高镇街道办",
        "调解成功数": 30,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 1,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 30,
        "name": "科甲社区人民调解委员会",
        "调解成功数": 16,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 7
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 30,
        "name": "双和社区人民调解委员会",
        "调解成功数": 30,
        "线上转诉": 1,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 29,
        "name": "望北社区人民调解委员会",
        "调解成功数": 26,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 29,
        "name": "嘉禾社区人民调解委员会",
        "调解成功数": 22,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 7
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 26,
        "name": "石井街新庄社区人民调解委员会",
        "调解成功数": 26,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 26,
        "name": "长湴社区人民调解委员会",
        "调解成功数": 25,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 26,
        "name": "西岭社区人民调解委员会",
        "调解成功数": 25,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 25,
        "name": "倚云天社区人民调解委员会",
        "调解成功数": 18,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 5,
        "录入总数": 24,
        "name": "白云区石井街道办",
        "调解成功数": 24,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 23,
        "name": "云祥社区人民调解委员会",
        "调解成功数": 17,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 23,
        "录入总数": 23,
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 23,
        "name": "棠溪社区人民调解委员会",
        "调解成功数": 21,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 21,
        "name": "云翠社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 15
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 20,
        "name": "江夏社区人民调解委员会",
        "调解成功数": 20,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 20,
        "name": "云苑西社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 15
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 20,
        "name": "隆康社区人民调解委员会",
        "调解成功数": 19,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 20,
        "name": "岗贝社区人民调解委员会",
        "调解成功数": 20,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 19,
        "name": "景泰西社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 9
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 19,
        "name": "金藤社区人民调解委员会",
        "调解成功数": 19,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 19,
        "name": "磨刀坑社区人民调解委员会",
        "调解成功数": 19,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 19,
        "name": "蓝山社区人民调解委员会",
        "调解成功数": 18,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 18,
        "name": "祥景花园社区人民调解委员会",
        "调解成功数": 18,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 18,
        "name": "新庄社区人民调解委员会",
        "调解成功数": 18,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 18,
        "name": "白云尚城社区人民调解委员会",
        "调解成功数": 18,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "白水塘社区人民调解委员会",
        "调解成功数": 16,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "广园中社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 15
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "金泰社区人民调解委员会",
        "调解成功数": 17,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "云苑东社区人民调解委员会",
        "调解成功数": 17,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "石湖村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 6
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "云苑南社区人民调解委员会",
        "调解成功数": 17,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "麦地社区人民调解委员会",
        "调解成功数": 16,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "京龙社区人民调解委员会",
        "调解成功数": 17,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "寮采村人民调解委员会",
        "调解成功数": 16,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 17,
        "name": "时代社区人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 6
      },
      {
        "调解中": 1,
        "小程序数": 0,
        "录入总数": 16,
        "name": "景泰东社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 16,
        "name": "景泰北社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 12
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 16,
        "name": "政通社区人民调解委员会",
        "调解成功数": 16,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 16,
        "name": "京宇社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 16,
        "name": "平安社区人民调解委员会",
        "调解成功数": 15,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "庆丰社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "金麟社区人民调解委员会",
        "调解成功数": 15,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "京鹏社区人民调解委员会",
        "调解成功数": 15,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "南湖半岛社区人民调解委员会",
        "调解成功数": 15,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "蟹山社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 15,
        "name": "棠下西社区人民调解委员会",
        "调解成功数": 15,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "夏茅利民社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "马岗社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 14,
        "name": "高尔夫社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "云景花园社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "机场西社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "长安社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "京海社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "梓元岗社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "富和花园社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 14,
        "name": "员村社区人民调解委员会",
        "调解成功数": 14,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "白云山制药厂社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "夏茅富民社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "百顺社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "大岭村人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "金湖社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "松北社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "大金钟社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 7
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "梅花园社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "梅苑社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 5
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "官厅窿社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 12
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "何屋社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "合益社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "竹园社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 13,
        "name": "榕溪社区人民调解委员会",
        "调解成功数": 13,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "马头岗社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "白山社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 2,
        "小程序数": 0,
        "录入总数": 12,
        "name": "广北社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "老庄社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "凤岭社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "石岗社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "石桥头社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "金迪社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "鹤边社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "大陂社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "斯文井社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "棠下南社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "东圣社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "元邦社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "犀牛角社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 12,
        "name": "景云社区人民调解委员会",
        "调解成功数": 12,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "白天鹅花园社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "白灰场社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "大朗货场社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "鸦湖村人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "福源社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "京麟社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "蟾蜍石社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "棠溪南社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 11,
        "name": "榕树头社区人民调解委员会",
        "调解成功数": 11,
        "线上转诉": 1,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "水边社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "广外大社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "朝阳第二社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "大沥村人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "钟落潭村人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "黄石第一社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "新凤社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "潭村北社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 10
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 10,
        "name": "倚绿山庄社区人民调解委员会",
        "调解成功数": 10,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "百荣社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 4
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "云龙社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "源山社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "滘心社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "竹二村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "春庭社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 9,
        "name": "颐和山庄社区人民调解委员会",
        "调解成功数": 9,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "夏良村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "良田村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "金碧雅苑社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "沙亭村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "松南社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "松涛北苑社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "陈田第二社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "白云区钟落潭镇街道办",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "米龙村人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "解放庄社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "光明村人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 8,
        "name": "连元桥社区人民调解委员会",
        "调解成功数": 8,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "金桂园社区人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "华园社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "沙溪村人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "恒骏花园社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "镇湖村人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "沙贝社区人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "南方医科大学社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 7,
        "name": "白云堡社区人民调解委员会",
        "调解成功数": 7,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "马务社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "红星联兴社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "金御苑南社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "云山居社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "云山诗意社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "鸦岗北社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "草庄村人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "机场第一社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "荷塘月色社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "大罗村人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 6,
        "name": "五龙岗村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "祥岗社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "黄石花园第二社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "黄边社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "龙安社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "东凤村人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "集贤庄社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "集贤苑社区人民调解委员会",
        "调解成功数": 6,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 6,
        "name": "走马岗社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "中医药大学社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "金域蓝湾社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "乐得社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "大围社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "石井社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "北村村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "茅山村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "江村村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "机场第三社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "南岗村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "萧岗南社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "钟落潭社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "虎塘村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "南浦村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "陈洞村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "新南庄社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "龙塘村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "竹一村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "双岗村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "富林社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "滘心南庄社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "白云区税务局",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 1,
        "本月新增": 0,
        "调解失败数": 3
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "新顺社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "西约社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "龙腾社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "明珠社区人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "平乐社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 2
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 5,
        "name": "园夏村人民调解委员会",
        "调解成功数": 5,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "红星亭岗社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "丰泰社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "马沥村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 4,
        "name": "乌溪村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "汇雅社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "高增村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "彭上社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "沙凤新村村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "心谊社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "金龙社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "沙田社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "萧岗花园社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "南悦第二社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "梅田村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "长腰岭村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "障岗村人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "龙归社区人民调解委员会",
        "调解成功数": 4,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 4,
        "name": "东约社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "两下村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "塘贝村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "平沙北社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "水沥村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "凤凰社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "永兴村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "罗溪村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "金德苑社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "朗头村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "大冈社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "金沙社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "江兴社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "朝阳第一社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "江华社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "高职园社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "张村社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "金碧新城社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "大朗南社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "江夏第二社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "华坑村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "鸦岗南社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "鸿图社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "大田村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "杨山村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "沙涌北社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "萧岗北社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "大石岗村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "鹤北社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "鹤南社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "五丰村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "萧岗得朋社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "鹤岗村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "松岗社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 1,
        "录入总数": 3,
        "name": "白云区景泰街道办",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "神山社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "柏塘村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "沙顶社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "蓼江村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "河心洲社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "南村村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "新兴白云花园社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "河畔社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "螺涌社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "齐富社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "穗丰村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "新村村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "侨德社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "小塘村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "新楼村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "雄丰村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "龙湖社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "东湖映月社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "龙穗社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "横滘望江社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "珠江村人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "两上村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 3,
        "name": "兴隆社区人民调解委员会",
        "调解成功数": 3,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "兵房社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "郭塘村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "凤冈社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "平沙南社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "罗南社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "凤和村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "汇德社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "高塘社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "聚龙村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "大朗北社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "机场北社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "彭西社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "荔德社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "南山社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "德圣社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "萧岗东安社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "鹅掌坦社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "石龙社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "南岭村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "怡德社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "南悦第一社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "大纲领村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "恒丰社区村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "沙田村村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "井岗村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "桥西社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "长岗村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "蝶云天社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "海苑社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "何㘵村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "竹三村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "上步社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "西洲社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "同景苑社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "同雅苑社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "龙悦社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "雄伟村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "岭南社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "明德社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "粤溪社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "谢家庄村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "唐阁社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "东苑社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "兴丰村人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "横滘社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 2,
        "name": "田心社区人民调解委员会",
        "调解成功数": 2,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "民强村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "登塘村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "白云区交警一大队",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 1
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "丽日社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "联升社区人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "广州市白云区三元里街白云新城片区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "勤星村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "华糖社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "御金沙社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "石榴桥社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "南悦第三社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "握山社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "南方村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "太成村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "安平村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "浔峰社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "积德社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "龙岗村人民调解委员会",
        "调解成功数": 0,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "西海岸社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "岗尾村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "竹料社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "潭村南社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "和珊社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "横沙社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "峡石村人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "紫竹社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "顺丰翠园社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      },
      {
        "调解中": 0,
        "小程序数": 0,
        "录入总数": 1,
        "name": "紫荆社区人民调解委员会",
        "调解成功数": 1,
        "线上转诉": 0,
        "司法确认数": 0,
        "本月新增": 0,
        "调解失败数": 0
      }
    ],
    "typeDistributionList": [
      {
        "case_type_name": "侵害其他著作财产权纠纷",
        "count": 6432,
        "case_type": "9343"
      },
      {
        "case_type_name": "邻里纠纷",
        "count": 514,
        "case_type": "22_00039-0004"
      },
      {
        "case_type_name": "领里纠纷",
        "count": 506,
        "case_type": "10003"
      },
      {
        "count": 480,
        "case_type": "1"
      },
      {
        "case_type_name": "劳动纠纷",
        "count": 423,
        "case_type": "1001"
      },
      {
        "case_type_name": "司法调解类",
        "count": 366,
        "case_type": "1003"
      },
      {
        "case_type_name": "劳动争议",
        "count": 303,
        "case_type": "9412"
      },
      {
        "case_type_name": "综治信访类",
        "count": 276,
        "case_type": "1002"
      },
      {
        "case_type_name": "合同纠纷",
        "count": 221,
        "case_type": "22_00039-0002"
      },
      {
        "case_type_name": "劳动纠纷",
        "count": 193,
        "case_type": "22_00039-0001"
      },
      {
        "count": 184,
        "case_type": "4"
      },
      {
        "case_type_name": "其他",
        "count": 173,
        "case_type": "22_00039-0017"
      },
      {
        "case_type_name": "小区纠纷",
        "count": 169,
        "case_type": "10004"
      },
      {
        "case_type_name": "家庭婚姻纠纷",
        "count": 131,
        "case_type": "22_00039-0005"
      },
      {
        "case_type_name": "房屋租赁合同纠纷",
        "count": 109,
        "case_type": "9174"
      },
      {
        "case_type_name": "劳务合同纠纷",
        "count": 93,
        "case_type": "9260"
      },
      {
        "count": 85,
        "case_type": "2"
      },
      {
        "case_type_name": "财产损害赔偿纠纷",
        "count": 76,
        "case_type": "22_00039-0013"
      },
      {
        "case_type_name": "合同纠纷",
        "count": 69,
        "case_type": "9118"
      },
      {
        "count": 67,
        "case_type": "19"
      },
      {
        "case_type_name": "物业管理纠纷",
        "count": 63,
        "case_type": "22_00039-0022"
      },
      {
        "count": 55,
        "case_type": "10"
      },
      {
        "case_type_name": "合同纠纷",
        "count": 53,
        "case_type": "10006"
      },
      {
        "case_type_name": "经济纠纷",
        "count": 48,
        "case_type": "22_00039-0018"
      },
      {
        "case_type_name": "经济纠纷",
        "count": 47,
        "case_type": "10005"
      },
      {
        "case_type_name": "物权纠纷",
        "count": 45,
        "case_type": "9041"
      },
      {
        "case_type_name": "合同、无因管理、不当得利纠纷",
        "count": 39,
        "case_type": "9117"
      },
      {
        "count": 38,
        "case_type": "12"
      },
      {
        "case_type_name": "环境污染纠纷",
        "count": 35,
        "case_type": "22_00039-0021"
      },
      {
        "case_type_name": "医疗纠纷",
        "count": 30,
        "case_type": "10008"
      },
      {
        "count": 30,
        "case_type": "18"
      },
      {
        "case_type_name": "情感纠纷",
        "count": 25,
        "case_type": "10002"
      },
      {
        "case_type_name": "侵权责任纠纷",
        "count": 22,
        "case_type": "9639"
      },
      {
        "case_type_name": "交通纠纷",
        "count": 22,
        "case_type": "10007"
      },
      {
        "case_type_name": "医疗产品责任纠纷",
        "count": 20,
        "case_type": "9656"
      },
      {
        "case_type_name": "生产经营纠纷",
        "count": 19,
        "case_type": "22_00039-0020"
      },
      {
        "count": 18,
        "case_type": "6"
      },
      {
        "case_type_name": "相邻污染侵害纠纷",
        "count": 15,
        "case_type": "9072"
      },
      {
        "case_type_name": "房屋宅基地纠纷",
        "count": 13,
        "case_type": "22_00039-0019"
      },
      {
        "case_type_name": "相邻用水、排水纠纷",
        "count": 11,
        "case_type": "9067"
      },
      {
        "case_type_name": "道路交通事故纠纷",
        "count": 10,
        "case_type": "22_00039-0006"
      },
      {
        "case_type_name": "相邻损害防免关系纠纷",
        "count": 10,
        "case_type": "9073"
      },
      {
        "case_type_name": "生命权、健康权、身体权纠纷",
        "count": 9,
        "case_type": "9003"
      },
      {
        "case_type_name": "医疗纠纷",
        "count": 8,
        "case_type": "22_00039-0007"
      },
      {
        "case_type_name": "不当得利纠纷",
        "count": 8,
        "case_type": "9266"
      },
      {
        "case_type_name": "提供劳务者受害责任纠纷",
        "count": 8,
        "case_type": "9645"
      },
      {
        "count": 8,
        "case_type": "17"
      },
      {
        "case_type_name": "恢复原状纠纷",
        "count": 7,
        "case_type": "9053"
      },
      {
        "case_type_name": "追索劳动报酬纠纷",
        "count": 7,
        "case_type": "9417"
      },
      {
        "case_type_name": "山林土地纠纷",
        "count": 6,
        "case_type": "22_00039-0015"
      },
      {
        "case_type_name": "水污染责任纠纷",
        "count": 6,
        "case_type": "9658"
      },
      {
        "case_type_name": "所有权纠纷",
        "count": 6,
        "case_type": "9055"
      },
      {
        "case_type_name": "人格权纠纷",
        "count": 5,
        "case_type": "22_00039-0011"
      },
      {
        "case_type_name": "财产损害赔偿纠纷",
        "count": 5,
        "case_type": "9054"
      },
      {
        "case_type_name": "劳动争议、人事争议",
        "count": 5,
        "case_type": "9411"
      },
      {
        "case_type_name": "噪声污染责任纠纷",
        "count": 5,
        "case_type": "9659"
      },
      {
        "case_type_name": "修理、重作、更换纠纷",
        "count": 5,
        "case_type": "9052"
      },
      {
        "case_type_name": "借贷纠纷",
        "count": 4,
        "case_type": "22_00039-0003"
      },
      {
        "case_type_name": "公共道路妨碍通行损害责任纠纷",
        "count": 4,
        "case_type": "9675"
      },
      {
        "case_type_name": "林木折断损害责任纠纷",
        "count": 4,
        "case_type": "9676"
      },
      {
        "case_type_name": "物件脱落、坠落损害责任纠纷",
        "count": 3,
        "case_type": "9671"
      },
      {
        "case_type_name": "人格权纠纷",
        "count": 3,
        "case_type": "9001"
      },
      {
        "case_type_name": "车位纠纷",
        "count": 3,
        "case_type": "9059"
      },
      {
        "case_type_name": "公共场所管理人责任纠纷",
        "count": 3,
        "case_type": "9647"
      },
      {
        "case_type_name": "物业服务合同纠纷",
        "count": 3,
        "case_type": "9251"
      },
      {
        "case_type_name": "所有权纠纷",
        "count": 2,
        "case_type": "22_00039-0009"
      },
      {
        "case_type_name": "继承纠纷",
        "count": 2,
        "case_type": "22_00039-0010"
      },
      {
        "case_type_name": "征地纠纷",
        "count": 2,
        "case_type": "22_00039-0016"
      },
      {
        "case_type_name": "建设用地使用权纠纷",
        "count": 2,
        "case_type": "22_00039-0014"
      },
      {
        "case_type_name": "抚养费纠纷",
        "count": 2,
        "case_type": "9023"
      },
      {
        "case_type_name": "大气污染责任纠纷",
        "count": 2,
        "case_type": "9657"
      },
      {
        "case_type_name": "相邻土地、建筑物利用关系纠纷",
        "count": 2,
        "case_type": "9069"
      },
      {
        "case_type_name": "民间借贷纠纷",
        "count": 2,
        "case_type": "9161"
      },
      {
        "case_type_name": "物权保护纠纷",
        "count": 2,
        "case_type": "9045"
      },
      {
        "case_type_name": "名誉权纠纷",
        "count": 2,
        "case_type": "9006"
      },
      {
        "case_type_name": "地面施工、地下设施损害责任纠纷",
        "count": 2,
        "case_type": "9677"
      },
      {
        "case_type_name": "相邻通行纠纷",
        "count": 2,
        "case_type": "9068"
      },
      {
        "case_type_name": "业主共有权纠纷",
        "count": 2,
        "case_type": "9058"
      },
      {
        "case_type_name": "用益物权确认纠纷",
        "count": 1,
        "case_type": "9047"
      },
      {
        "case_type_name": "不明抛掷物、坠落物损害责任纠纷",
        "count": 1,
        "case_type": "9673"
      },
      {
        "case_type_name": "返还原物纠纷",
        "count": 1,
        "case_type": "9049"
      },
      {
        "case_type_name": "确认劳动关系纠纷",
        "count": 1,
        "case_type": "9413"
      },
      {
        "case_type_name": "饲养动物损害责任纠纷",
        "count": 1,
        "case_type": "9670"
      },
      {
        "case_type_name": "人事争议",
        "count": 1,
        "case_type": "9426"
      },
      {
        "case_type_name": "离婚纠纷",
        "count": 1,
        "case_type": "9015"
      },
      {
        "case_type_name": "供用水合同纠纷",
        "count": 1,
        "case_type": "9153"
      },
      {
        "case_type_name": "居间合同纠纷",
        "count": 1,
        "case_type": "9219"
      },
      {
        "case_type_name": "用益物权纠纷",
        "count": 1,
        "case_type": "9077"
      },
      {
        "case_type_name": "工伤保险待遇纠纷",
        "count": 1,
        "case_type": "9421"
      },
      {
        "case_type_name": "遗失物返还纠纷",
        "count": 1,
        "case_type": "9063"
      },
      {
        "case_type_name": "高度危险活动损害责任纠纷",
        "count": 1,
        "case_type": "9667"
      },
      {
        "case_type_name": "适用特殊程序案件案由",
        "count": 1,
        "case_type": "9696"
      },
      {
        "case_type_name": "继承纠纷",
        "count": 1,
        "case_type": "9034"
      },
      {
        "case_type_name": "相邻通风纠纷",
        "count": 1,
        "case_type": "9070"
      },
      {
        "case_type_name": "赡养费纠纷",
        "count": 1,
        "case_type": "9027"
      },
      {
        "case_type_name": "业主撤销权纠纷",
        "count": 1,
        "case_type": "9061"
      },
      {
        "case_type_name": "建设工程施工合同纠纷",
        "count": 1,
        "case_type": "9187"
      },
      {
        "case_type_name": "排除妨害纠纷",
        "count": 1,
        "case_type": "9050"
      },
      {
        "case_type_name": "相邻采光、日照纠纷",
        "count": 1,
        "case_type": "9071"
      },
      {
        "case_type_name": "消除危险纠纷",
        "count": 1,
        "case_type": "9051"
      },
      {
        "case_type_name": "福利待遇纠纷",
        "count": 1,
        "case_type": "9425"
      },
      {
        "case_type_name": "特许经营合同纠纷",
        "count": 1,
        "case_type": "9323"
      },
      {
        "case_type_name": "加工合同纠纷",
        "count": 1,
        "case_type": "9178"
      },
      {
        "case_type_name": "其他纠纷",
        "count": 0
      }
    ]
  }
}
const MediateBigData = () => {
  //起始时间 和 结束时间 
  const currentYear = new Date().getFullYear();
  const firstDayOfYear = new Date(currentYear, 0, 2); //从31号算起 故这里为2
  const formattedDate = firstDayOfYear.toISOString().slice(0, 10);
  const today = new Date();
  const timeEnd = today.toISOString().slice(0, 10);
  const firstDayOfMonth = new Date(today.getFullYear(), today.getMonth(), 2).toISOString().slice(0, 10);
  const [form] = Form.useForm();
  //所有案件信息-用于调解总览部分
  const [allCanal, setAllCanal] = useState([]);
  //工作排名
  const [workTopList, setWorkTopList] = useState([]);
  //实时动态-表格
  const [realTimeDynamicList, setRealTimeDynamicList] = useState([]);
  //趋势分析
  const [trendAnalysisList, setTrendAnalysisList] = useState([]);
  /**
   * 
   */
  //时间选择的值
  const [timeRadioValue, setTimeRadioValue] = useState(1);
  //组件是否显示
  const [showSelect, setShowSelect] = useState(false);
  const [showRangePicker, setRangePicker] = useState(false);
  const [showMonthCard, setShowMonthCard] = useState(true);

  //单选框-
  const [statisticalRange, setStatisticalRange] = useState('本单位和全部下级单位');

  const [selectedOption, setSelectedOption] = useState('全部');
  //日期框-开始时间和结束时间 同于提示框显示
  const { RangePicker } = DatePicker;
  const [startTime, setStartTime] = useState('全年（' + formattedDate);
  const [endTime, setEndTime] = useState('今)');

  // 测试数据 后续删
  const options = [
    {
      value: 'parent 1',
      title: 'parent 1',
      children: [
        {
          value: 'parent 1-0',
          title: 'parent 1-0',
          children: [
            {
              value: 'leaf1',
              title: 'leaf1',
            },
            {
              value: 'leaf2',
              title: 'leaf2',
            },
          ],
        },
        {
          value: 'parent 1-1',
          title: 'parent 1-1',
          children: [
            {
              value: 'leaf3',
              title: <b style={{ color: '#08c' }}>leaf3</b>,
            },
          ],
        },
      ],
    },
  ];
  //饼图-单选框值 
  const [originOfTypeDistribution, setOriginOfTypeDistribution] = useState('机构');

  //趋势分析-单选框值
  const [originOfTrendAnalysis, setOriginOfTrendAnalysis] = useState('收集情况');

  //工作排名-单选框值
  const [originOfWorkloadRanking, setOriginOfWorkloadRanking] = useState('收案数');
  //饼图-函数
  const changeOriginOfTypeDistribution = (e) => {
    setOriginOfTypeDistribution(e.target.value);
  };


  //提示框Alter是否可见
  const [alertVisible, setAlertVisible] = useState(true);

  //趋势分析-单选框函数
  const changeOriginOfTrendAnalysis = (e) => {
    setOriginOfTrendAnalysis(e.target.value);
  };

  //工作排名-单选框函数
  const changeOriginOfWorkloadRanking = (e) => {
    setOriginOfWorkloadRanking(e.target.value);
  };

  //选择器
  const handleSelection = (value) => {
    //选择器更改 同时更改提示框
    setStatisticalRange(value);
    setSelectedOption(value);
  };

  //Alter关闭的函数
  const handleAlertClose = () => {
    setAlertVisible(false);
  };


  //statisticalRange 选择器是否显示
  const onStatisticalRangeChange = (e) => {
    if (e.target.value === '全部下级单位') {
      console.log('执行了 选择器')
      // 当选中自定义时，显示日期选择框
      setStatisticalRange(e.target.value);
      setShowSelect(true);
    } else {
      setShowSelect(false);
      setStatisticalRange(e.target.value);
    }

  };


  //日期选择框是否显示
  const onTimeRadioChange = (e) => {
    // console.log('执行了')
    setTimeRadioValue(e.target.value);
    if (e.target.value === 1) {
      setStartTime('全年（' + formattedDate)
      setEndTime('今)')
      console.log('dasd ', startTime)
      setRangePicker(false);

      setShowMonthCard(true);
    } else {
      setRangePicker(true);
      //设置总览的2张卡片不展示
      setShowMonthCard(false);
    }

  };
  //获取日期框的开始日期和结束日期
  const handleRangeChange = (dates, dateStrings) => {
    setStartTime(dateStrings[0])
    setEndTime(dateStrings[1])
  };

  // 搜索 or 重置
  function handleSearch (type, data) {
    if (type === 'recovery') {
      // 详情返回时恢复跳转前查询
      let obj = Object.assign({}, data.search);
      $$.changeTimeFormat(obj, 'createTime', 'createStart', 'createEnd');
      form.setFieldsValue(obj);
      // getData(obj, data.tableActive);
      return;
    }
    if (type === 'search') {
      let values = form.getFieldsValue();
      $$.changeTimeFormat(values, 'createTime', 'createStart', 'createEnd');
      // getData({ ...search, ...values, page: 1 });
      return;
    }
    if (type === 'reset') {
      setTimeRadioValue(1);
      setShowSelect(false);
      setRangePicker(false);
      setStatisticalRange('本单位和全部下级单位');
      setEndTime('今)')
      setStartTime('全年（' + formattedDate)
      // getData(data);
    }
  }
  //4张卡片滑动需要的参数
  const [downX, setDownX] = useState(0);
  const [moveX, setMoveX] = useState(0);
  const [scrollX, setScrollX] = useState(0);
  const drawRef = useRef(null);
  const [scrollFlag, setScrollFlag] = useState(true);
  const [scrollPosition, setScrollPosition] = useState(0);

  const getMouseStart = (e) => {
    setScrollFlag(true)
    setDownX(e.clientX)
    setScrollPosition(drawRef.current.scrollLeft)
  };

  const getMouseMove = (e) => {
    if (scrollFlag) {
      const container = drawRef.current;
      setMoveX(e.clientX);
      setScrollX(moveX - downX);
      if (scrollX < 0 && scrollPosition > 0) {
        console.log('scX ', scrollX)
        container.scrollLeft = scrollPosition - scrollX;
        setScrollPosition(scrollPosition - scrollX);
      } else {
        container.scrollLeft = scrollPosition - scrollX;
        setScrollPosition(scrollPosition - scrollX);
      }
    }
  };

  const getMouseUp = (e) => {
    setScrollFlag(false)
  };

  const realTimeData_tableColumns = [
    {
      title: '案件标题',
      dataIndex: 'title',
      width: 230
    },
    {
      title: '办理进度',
      dataIndex: 'progress',
    },
    {
      title: '办理时间',
      dataIndex: 'time',
      width: 150
    },
    {
      title: '调解组织',
      dataIndex: 'organization',
      width: 180
    },
    {
      title: '调解员',
      dataIndex: 'mediator',
    }
  ];
  const realTimeData_tableData = [
    {
      key: '1',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '指派调解员',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '2',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '3',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '4',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '5',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '6',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '7',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '8',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '9',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '10',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '11',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '12',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '13',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '14',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '15',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '16',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '17',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '18',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '19',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '20',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '21',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '22',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '23',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '24',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '25',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '26',
      title: '张三和李晓明就劳动争议调解案件26',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '27',
      title: '张三和李晓明就劳动争议调解案件27',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '28',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '29',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    },
    {
      key: '30',
      title: '张三和李晓明就劳动争议调解案件',
      progress: '新收案件',
      time: '2023-5-8 16:00:00',
      organization: '新市街道人民调解委员会',
      mediator: '李晓明',
    }

  ]

  //环图
  const TypeDistribution_Pie = () => {
    function renderStatistic (containerWidth, text, style) {
      const { width: textWidth, height: textHeight } = measureTextWidth(text, style);
      const R = containerWidth / 2; // r^2 = (w / 2)^2 + (h - offsetY)^2

      let scale = 1;

      if (containerWidth < textWidth) {
        scale = Math.min(Math.sqrt(Math.abs(Math.pow(R, 2) / (Math.pow(textWidth / 2, 2) + Math.pow(textHeight, 2)))), 1);
      }

      const textStyleStr = `width:${containerWidth}px`;
      return `<div style="${textStyleStr};font-size:14px;line-height:${scale < 1 ? 1 : 'inherit'};">${text}</div>`;
    }

    const data = [
      {
        type: '民间借贷',
        value: 27,
      },
      {
        type: '婚姻家事',
        value: 25,
      },
      {
        type: '劳动争议',
        value: 18,
      },
      {
        type: '知识产权',
        value: 15,
      },
      {
        type: '其他',
        value: 5,
      },
    ];
    const config = {
      appendPadding: 10,
      data,
      angleField: 'value',
      colorField: 'type',
      color: ({ type }) => {
        if (type === '民间借贷') {
          return '#FFE6E6';
        }
        if (type === '婚姻家事') {
          return '#FFA6A6';
        }
        if (type === '劳动争议') {
          return '#EB4D58';
        }
        if (type === '知识产权') {
          return '#D1021C';
        }
        if (type === '其他') {
          return '#AB001C';
        }
      },
      radius: 1,
      innerRadius: 0.64,
      meta: {
        value: {
          formatter: (v) => `${(v / data.reduce((total, item) => total + item.value, 0) * 100)}%`,
        },
      },
      label: {
        type: 'inner',
        offset: '-50%',
        style: {
          textAlign: 'center',
          fontSize: 12,
          fill: 'rgba(0, 0, 0, 0.85)',
        },
        autoRotate: false,
        content: '{value}%',
      },
      statistic: {
        title: {
          offsetY: -4,
          customHtml: (container, view, datum) => {
            const { width, height } = container.getBoundingClientRect();
            const d = Math.sqrt(Math.pow(width / 2, 2) + Math.pow(height / 2, 2));
            const text = datum ? datum.type : '收案总数';
            return renderStatistic(d, text, {
              fontSize: 12,
            });
          },
        },
        content: {
          offsetY: 4,
          style: {
            fontSize: 14
          },
          customHtml: (container, view, datum, data) => {
            const { width } = container.getBoundingClientRect();
            const sum = `${data.reduce((r, d) => r + d.value, 0)}`;
            // const percentage = `${(datum.value / sum * 100).toFixed(0)}`;
            const text = datum ? `${(datum.value / sum * 100).toFixed(0)}%` : `${(data.reduce((r, d) => r + d.value, 0))}%`;
            return renderStatistic(width, text, {
              fontSize: 32,
            });
          },
        },
      },
      // 添加 中心统计文本 交互
      interactions: [
        {
          type: 'element-selected',
        },
        {
          type: 'element-active',
        },
        {
          type: 'pie-statistic-active',
        },
      ],
    };
    return <Pie {...config} />;
  };

  // 传入折线图的参数
  const [searchTotal, setSearchTotal] = useState('1');

  const { roleId } = useOutletContext();
  // 折线图
  const MyChart = ({ searchChart, roleId }) => {
    const myChartRef = useRef();
    // 图表
    const [myChart, setMyChart] = useState();

    // 加载趋势分析-折线图数据
    useEffect(() => {
      let isMounted = true;
      if (!roleId) return;
      async function getChartData () {
        if (myChart) myChart.changeData([]);
        const res = await getChartDataApi({ countRange: searchChart });
        if (res.type && isMounted) {
          let data = res.data || [];
          if (!myChart) {
            const chart = new Chart({ container: 'container', autoFit: true });
            chart.data(data);
            chart.scale({ month: { range: [0, 1] }, num: { min: 0, nice: true } });
            chart.tooltip({ showCrosshairs: true, shared: true, axisPointer: { type: 'line' } });
            chart.line().position('month*num').color('type', ['#1890FF', '#05AEAE', '#EF6C24']).shape('line');
            chart.axis('month', {
              line: null,
              grid: {
                line: {
                  style: {
                    stroke: 'rgba(0,0,0,0.20)',
                    lineDash: [1, 1]
                  },
                },
              },
            });
            chart.axis('num', {
              line: {
                style: {
                  stroke: 'rgba(0,0,0,0.15)',
                },
              },
              grid: {
                line: {
                  style: {
                    stroke: 'rgba(0,0,0,0.20)',
                    lineDash: [1, 1]
                  },
                },
              },
            });
            // chart.point().position('month*num').color('type', ['#1890FF', '#05AEAE', '#EF6C24']).shape('circle');
            chart.render();
            setMyChart(chart);
          } else {
            myChart.changeData(data);
          }
        }
      }
      getChartData();
      return () => {
        isMounted = false;
      };
    }, [searchChart, roleId]);

    useEffect(() => {
      if (myChart && myChartRef.current.clientHeight !== 0) {
        myChart.forceFit();
      }
    });

    return <div id="container" ref={myChartRef} style={{ height: '100%' }} />;
  };

  // Progress
  const RankProgress = ({ percent, color }) => {
    const config = {
      height: 27.1,
      width: 365,
      autoFit: false,
      percent: percent,
      barWidthRatio: 0.3,
      color: color
    }
    return <Progress {...config} />;
  };


  //统计筛选的折线图的列名和 数据
  const reportStatisticsColumns = [
    {
      title: '序号',
      dataIndex: 'id',
    },
    {
      title: '调解组织',
      dataIndex: 'name',
    },
    {
      title: '录入总数',
      dataIndex: 'chinese',
      sorter: {
        compare: (a, b) => a.chinese - b.chinese,
        multiple: 3,
      },
      defaultSortOrder: 'descend' // 设置默认排序方式为降序
    },
    {
      title: '调解成功数',
      dataIndex: 'math',
      sorter: {
        compare: (a, b) => a.math - b.math,
        multiple: 2,
      },
    },
    {
      title: '正在调解数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
    },
    {
      title: '司法确认数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
    },
    {
      title: '小程序申请案件数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
      width: 145
    },
    {
      title: ' 本月新增数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
    },
    {
      title: '调解失败数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
    },
    {
      title: '线上转诉案件数',
      dataIndex: 'english',
      sorter: {
        compare: (a, b) => a.english - b.english,
        multiple: 1,
      },
      width: 135
    }
  ];
  const reportStatisticsData = [
    {
      key: '1',
      id: '1',
      name: 'John Brown',
      chinese: 98,
      math: 60,
      english: 70,
    },
    {
      key: '2',
      id: '2',
      name: 'Jim Green',
      chinese: 98,
      math: 66,
      english: 89,
    },
    {
      key: '3',
      id: '3',
      name: 'Joe Black',
      chinese: 98,
      math: 90,
      english: 70,
    },
    {
      key: '4',
      name: 'Jim Red',
      chinese: 88,
      math: 99,
      english: 89,
    },
    // {
    //   key: '4',
    //   name: 'Jim Red',
    //   chinese: 88,
    //   math: 99,
    //   english: 89,
    // },
    // ,
    // {
    //   key: '4',
    //   name: 'Jim Red',
    //   chinese: 88,
    //   math: 99,
    //   english: 89,
    // },
    // ,
    // {
    //   key: '4',
    //   name: 'Jim Red',
    //   chinese: 88,
    //   math: 99,
    //   english: 89,
    // },
  ];

  const onReportStatisticsChange = (pagination, filters, sorter, extra) => {
    console.log('params', pagination, filters, sorter, extra);
  };

  // table选择数据
  const [selectedRowsObj, setSelectedRowsObj] = useState({});

  // 搜索
  const [search, setSearch] = useState({ page: 1, size: 10 });

  // 数据
  const [data, setData] = useState({ key: new Date() });

  // 获取待调度数据
  // async function getData (submitData, tableActive) {
  //   global.setSpinning(true);
  //   const res = await getMyMediationDataApi(submitData);
  //   global.setSpinning(false);
  //   if (res.type) {
  //     setSearch(submitData);
  //     setData({ total: res.data?.totalElements, tableData: res.data?.content || [], tableActive });
  //   }
  // }

  // 导出表格
  async function ExportTable () {

    let list = [];
    list = realTimeData_tableColumns;
    if (list.length == 0) {
      $$.info({ type: 'error', content: '暂无数据可以导出' });
    } else {
      $$.modalInfo({
        title: '导出查询结果确认',
        content: <span>确认导出当前查询结果包含的<span className='ledger-main-title'>全部案件信息</span> 吗？</span>,
        okText: '确定导出',
        cancelText: '我再想想',
        onOk: async () => {
          // console.log('search', object.keys(search));
          let data = JSON.parse(JSON.stringify(search));
          let params = $$.getQueryObj(data);
          let userId = $$.getLocal('customerSystemUser')?.userId;
          // window.open(`${$$.appUrl.baseUrl}${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId${userId}`);
          // console.log('data', `${$$.appUrl.baseUrl}${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId${userId}`);
          window.location.href = `${$$.appUrl.baseUrl}/${$$.appUrl.mediate}/api/v1/caseInfo/exportListToExcel?${params}userId=${userId}`;
        },
      });
    }
  }
  // 初始化
  useEffect(() => {
    console.log(timeEnd)
    if (!roleId) return; //判断角色信息
    // 获取平台案件数量数据 and 待办事项
    async function getAllData () {
      global.setSpinning(true);
      // const res = await getAllDataApi({ countRange: '1', timeType: '1', formattedDate, timeEnd });
      global.setSpinning(false);

      setWorkTopList(resTest.workTopList);

      setAllCanal(resTest.allCanal);

      setRealTimeDynamicList(resTest.setRealTimeDynamicList);

      setTrendAnalysisList(resTest.trendAnalysisList);

    }
    getAllData();
  }, []);


  return (
    <Page pageHead={{
      title: '调解大数据', subtitle: <span>实时统计分析不同渠道进入多元化解平台的<span className='font-red'>调解案件</span>数据，利用数字化技术生成纠纷化解的最新态势</span>
    }}>
      <div>
        <div className='mediateBigData mediateBigData-card statisticalflterin-size' >
          <div className='statisticalflterin-title' >
            <div className='red-icon' ></div>
            <span>统计筛选</span>
          </div>
          <Row >
            <Col span={12} >
              <div className='statisticalflterin-body'>
                <span>统计范围：</span>
                <Radio.Group onChange={onStatisticalRangeChange} value={statisticalRange} defaultValue={'本单位和全部下级单位'}>
                  <Radio value={'本单位和全部下级单位'}>全部</Radio>
                  <Radio value={'本单位'}>本单位</Radio>
                  <Radio value={'全部下级单位'}>下级单位</Radio>
                </Radio.Group>
                {showSelect && <TreeSelect defaultValue='全部' className='select' onChange={handleSelection} treeData={options} treeDefaultExpandAll />}
              </div>
            </Col>
            <Col span={12} >
              <div className='statisticalflterin-body' >
                <span >统计时间：</span>
                <Radio.Group onChange={onTimeRadioChange} value={timeRadioValue} >
                  <Radio value={1}>全年</Radio>
                  <Radio value={2}>自定义</Radio>
                </Radio.Group>
                {showRangePicker && <RangePicker onChange={handleRangeChange} className='rangePicker' />}
                <Space className='statisticalflterin-button'>
                  <Button onClick={() => handleSearch('reset', statisticalRange)} >
                    重置
                  </Button>
                  <Button type="primary" htmlType="submit" >
                    统计
                  </Button>
                </Space>
              </div>
            </Col>
          </Row>
        </div>
        {alertVisible && (
          <Alert className='alertStyle' message={
            <span>已为您生成<span className='font-red'>{statisticalRange}</span>在<span className='font-red'>{startTime}</span><span className='font-red'>至</span><span className='font-red'>{endTime}</span>的调解大数据统计分析看板</span>
          } type="info" closable afterClose={handleAlertClose} showIcon icon={<img src={mediateBigData_1} className='alertIcon' alt="info-icon" />} />
        )}

        {/* 这是调解总览 */}
        <Row className='marginRight' >
          <Col span={7}>
            <div className='mediationOverview mediateBigData-card'>
              <div className='mediationOverview-title' >
                <div className='red-icon'></div>
                <span >调解总览</span>
              </div>
              <Card className='mediationOverview-border'>
                <Card.Grid hoverable={false} className='gridStyle1 mediationOverview-griddOne' >
                  <div className='mediationOverview-font gridd-title' >收案总数</div>
                  <div className='gridd-sumNum mediationOverview-num' >{resTest.data.allCanal.总数}</div>
                  <Divider className='divider-margin' />
                  <div className='griddOneAndThree-body marginRightOneAndThree' >
                    <div className='griddOne-fontbackgroundCommon '>
                      <span className='mediationOverview-font griddOneAndThree-title2'>未开始</span>
                    </div>
                    <span className='mediationOverview-space'></span>
                    <div className='griddOne-fontbackgroundCommon '>
                      <span className='mediationOverview-font griddOneAndThree-title3' >调解中</span>
                    </div>
                    <span className='mediationOverview-space'></span>
                    <div className='griddOne-fontbackgroundCommon '>
                      <span className='mediationOverview-font griddOneAndThree-title4'>已结束</span>
                    </div>
                  </div>
                  <div className='mediationOverview-margin marginRightOneAndThree'>
                    <div className='griddOne-numbackgroundCommon griddOne-num1Bg' >
                      <span className='mediationOverview-num griddOne-num1'>171</span>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space' ></span>

                    <div className='griddOne-numbackgroundCommon griddOne-num2Bg'>
                      <span className='mediationOverview-num griddOne-num2'>171</span>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space'></span>

                    <div className='griddOne-numbackgroundCommon griddOne-num3Bg'>
                      <span className='mediationOverview-num griddOne-num3'>50</span>
                    </div>
                  </div>
                </Card.Grid>
                {showMonthCard && <Card.Grid hoverable={false} className='gridStyle mediationOverview-griddTwo'>
                  <div className='mediationOverview-font gridd-title' >本月新增</div>
                  <div className='gridd-sumNum mediationOverview-num' >96</div>
                  <Divider className='divider-margin' />
                  <div className='griddTwoAndFour-tongBi ' >
                    <span className='mediationOverview-margin mediationOverview-font griddTwoAndFour-title1'>同比</span>
                    <span className='mediationOverview-margin mediationOverview-num  griddTwoAndFour-num1'>
                      {'+123.8%'}
                    </span>
                  </div>
                  <div className='griddTwoAndFour-tongBi '>
                    <span className='mediationOverview-margin mediationOverview-font griddTwoAndFour-title2'>环比</span>
                    <span className='mediationOverview-margin mediationOverview-num  griddTwoAndFour-num2'>{'-13.8%'}</span>
                  </div>
                </Card.Grid>}
              </Card>
              <Card className='mediationOverview-border'>
                <Card.Grid hoverable={false} className='gridStyle1 mediationOverview-griddThree'>
                  <div className='mediationOverview-font gridd-title' >调解成功率</div>
                  <div className='gridd-sumNum mediationOverview-num' >98.3%</div>
                  <Divider className='divider-margin' />
                  <div className='griddOneAndThree-body marginRightOneAndThree' >
                    <div className='griddOne-fontbackgroundCommon '>
                      <div className='mediationOverview-font griddOneAndThree-title2 griddOneAndThree-title2-margin '>成功</div>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space'></span>
                    <div className='griddOne-fontbackgroundCommon '>
                      <span className='mediationOverview-font griddOneAndThree-title3' >不成功</span>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space'></span>
                    <div className='griddOne-fontbackgroundCommon '>
                      <span className='mediationOverview-font griddOneAndThree-title4'>转诉讼</span>
                    </div>
                  </div>
                  <div className='mediationOverview-margin marginRightOneAndThree'>
                    <div className='griddOne-numbackgroundCommon griddThree-num1Bg' >
                      <span className='mediationOverview-num griddThree-num1'>171</span>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space' ></span>

                    <div className='griddOne-numbackgroundCommon griddThree-num2Bg'>
                      <span className='mediationOverview-num griddThree-num2'>171</span>
                    </div>
                    {/* 间隔 */}
                    <span className='mediationOverview-space'></span>

                    <div className='griddOne-numbackgroundCommon griddThree-num3Bg'>
                      <span className='mediationOverview-num griddThree-num3'>50</span>
                    </div>
                  </div>
                </Card.Grid>

                {showMonthCard && <Card.Grid hoverable={false} className='gridStyle mediationOverview-griddFour'>
                  <div className='mediationOverview-font gridd-title' >本月调解成功率</div>
                  <div className='gridd-sumNum mediationOverview-num' >60.3%</div>
                  <Divider className='divider-margin' />
                  <div className='griddTwoAndFour-tongBi ' >
                    <span className='mediationOverview-margin mediationOverview-font griddTwoAndFour-title1'>同比</span>
                    <span className='mediationOverview-margin mediationOverview-num  griddTwoAndFour-num1'>
                      {'+123.8%'}
                    </span>
                  </div>
                  <div className='griddTwoAndFour-tongBi '>
                    <span className='mediationOverview-margin mediationOverview-font griddTwoAndFour-title2'>环比</span>
                    <span className='mediationOverview-margin mediationOverview-num  griddTwoAndFour-num2'>{'-13.8%'}</span>
                  </div>
                </Card.Grid>}
              </Card>
            </div>
          </Col>
          {/*三种情况的案件数 和 4张卡片*/}
          <Col span={17}  >
            <Row className='mediateBigData-card countByIssueCard'  >
              <Col  >
                <div className='countByIssueCard-div' >
                  <span className='countByIssueCard-serious' >
                    <img className='serious-img' src={mediateBigData_2} />
                    <span >
                      <Row className='countByIssueCard-divider'>
                        <Col className='divider-colInline'>
                          <div className='divider1-paddingTop' >
                            <div className='countByIssueCard-divider1'></div>
                          </div>
                        </Col>
                        <Col className='divider-colInline'>
                          <Row>
                            <span className='mediationOverview-font'>严重超过处置时限<span className='mediationOverview-num serious-num'>123</span>件</span>
                          </Row>
                        </Col>
                        <Row>
                          <div className='countByIssueCard-divider2' ></div>
                          <div className='countByIssueCard-divider3' ></div>
                        </Row>
                      </Row>
                    </span>
                  </span>
                  <span className='countByIssueCard-warn'>
                    <img src={mediateBigData_3} />
                    <span >
                      <Row className='countByIssueCard-divider '>
                        <Col className='divider-colInline'>
                          <div className='divider1-paddingTop' >
                            <div className='countByIssueCard-divider1'></div>
                          </div>
                        </Col>
                        <Col className='divider-colInline'>
                          <Row>
                            <span className='mediationOverview-font'>轻微超过处置时限<span className='mediationOverview-num serious-num'>440</span>件</span>
                          </Row>
                        </Col>
                        <Row>
                          <div className='countByIssueCard-divider2' ></div>
                          <div className='countByIssueCard-divider3' ></div>
                        </Row>
                      </Row>
                    </span>
                  </span>
                  <span className='countByIssueCard-info'>
                    <img src={mediateBigData_4} />
                    <span >
                      <Row className='countByIssueCard-divider'>
                        <Col className='divider-colInline'>
                          <div className='divider1-paddingTop' >
                            <div className='countByIssueCard-divider1'></div>
                          </div>
                        </Col>
                        <Col className='divider-colInline'>
                          <Row>
                            <span className='mediationOverview-font'>处置进度正常<span className='mediationOverview-num serious-num'>123</span>件</span>
                          </Row>
                        </Col>
                        <Row>
                          <div className='countByIssueCard-divider2' ></div>
                          <div className='countByIssueCard-divider4'></div>
                        </Row>
                      </Row>
                    </span>
                  </span>
                </div>
              </Col>
            </Row>
            {/* 四张卡片 */}
            <Row  >
              <Col flex='auto' >
                <div class='outer-container'>
                  <div className='scroll-container no_copy' ref={drawRef} onMouseDown={getMouseStart} onMouseMove={getMouseMove} onMouseUp={getMouseUp}>
                    <div className='scroll-item'>
                      <div>
                        <Row>
                          <Col className='item1-headBg1' >
                            <div className='headLeft1-Bg'>
                              <img src={mediateBigData_8} />
                            </div>
                          </Col>
                          <Col className='item1-headBg2' flex='auto'>
                            <Row className='headRight-title'>机构登记</Row>
                            <Row className='headRight-num'>961</Row>
                          </Col>
                        </Row>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-title1'>个体登记</span>
                        <span className=' mediationOverview-font body-title2'>案件导入</span>
                      </div>

                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num1'>220</span>
                        <span className='mediationOverview-num body-num2'>123</span>
                      </div>
                      <div >
                        <span className='mediationOverview-font  body-title3 scrollCardMargin'>调解成功</span>
                        <span className='mediationOverview-font body-title4' >调解中</span>
                        <span className='mediationOverview-font body-title5'>调解不成功</span>
                      </div>
                      <div>
                        <span className=' mediationOverview-num body-num3 scrollCardMargin'>220</span>
                        <span className='mediationOverview-num body-num4'>123</span>
                        <span className='mediationOverview-num body-num5'>123</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-tittle6'>调解成功率</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num6'>220</span>
                      </div>
                    </div>

                    <div className='scroll-item'  >
                      <div >
                        <Row>
                          <Col className='item2-headBg1'>
                            <div className='headLeft2-Bg'>
                              <img src={mediateBigData_6} />
                            </div>
                          </Col>
                          <Col className='item2-headBg2' flex='auto'>
                            <div className='headRight-title'>小程序申请</div>
                            <div className='headRight-num'>961</div>
                          </Col>
                        </Row>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-title1'>不予授理</span>
                        <span className=' mediationOverview-font body-title2'>撤回调解</span>
                        <span className=' mediationOverview-font item2-title3'>待调解</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num1'>220</span>
                        <span className='mediationOverview-num body-num2'>123</span>
                        <span className='mediationOverview-num item2-num3'>123</span>
                      </div>
                      <div >
                        <span className='mediationOverview-font  body-title3 scrollCardMargin'>调解成功</span>
                        <span className='mediationOverview-font body-title4' >调解中</span>
                        <span className='mediationOverview-font body-title5'>调解不成功</span>
                      </div>
                      <div>
                        <span className=' mediationOverview-num body-num3 scrollCardMargin'>220</span>
                        <span className='mediationOverview-num body-num4'>123</span>
                        <span className='mediationOverview-num body-num5'>123</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-title6'>调解成功率</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num6'>220</span>
                      </div>
                    </div>

                    <div className='scroll-item'>
                      <div >
                        <Row className='verticalSetting'>
                          <Col className='item3-headBg1'>
                            <div className='headLeft3-Bg'>
                              <img src={mediateBigData_7} />
                            </div>
                          </Col>
                          <Col className='item3-headBg2' flex='auto'>
                            <div className='headRight-title'>人民调解系统转入</div>
                            <div className='headRight-num'>961</div>
                          </Col>
                        </Row>
                      </div>
                      <div className='item3-body'>
                        <div>
                          <span className='mediationOverview-font item3-title1'>调解成功</span>
                          <span className='mediationOverview-font item3-title2' >调解中</span>
                          <span className='mediationOverview-font item3-title3'>调解不成功</span>
                        </div>
                        <div>
                          <span className='mediationOverview-num item3-num1'>220</span>
                          <span className='mediationOverview-num item3-num2'>123</span>
                          <span className='mediationOverview-num item3-num3'>123</span>
                        </div>
                        <div>
                          <span className='mediationOverview-font item3-title4'>调解成功率</span>
                        </div>
                        <div>
                          <span className='mediationOverview-num item3-num4'>220</span>
                        </div>
                        <div>
                          <span className=' verticalSetting'></span>
                        </div>
                      </div>
                    </div>

                    <div className='scroll-item'  >
                      <div >
                        <Row>
                          <Col className='item4-headBg1'>
                            <div className='headLeft4-Bg'>
                              <img src={mediateBigData_5} />
                            </div>
                          </Col>
                          <Col className='item4-headBg2' flex='auto'>
                            <div className='headRight-title'>机构登记</div>
                            <div className='headRight-num'>961</div>
                          </Col>
                        </Row>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-title1'>个体登记</span>
                        <span className=' mediationOverview-font body-title2'>案件导入</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num1'>220</span>
                        <span className='mediationOverview-num body-num2'>123</span>
                      </div>
                      <div >
                        <span className='mediationOverview-font  body-title3 scrollCardMargin'>调解成功</span>
                        <span className='mediationOverview-font body-title4' >调解中</span>
                        <span className='mediationOverview-font body-title5'>调解不成功</span>
                      </div>
                      <div>
                        <span className=' mediationOverview-num body-num3 scrollCardMargin'>220</span>
                        <span className='mediationOverview-num body-num4'>123</span>
                        <span className='mediationOverview-num body-num5'>123</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-font body-title6'>调解成功率</span>
                      </div>
                      <div>
                        <span className='scrollCardMargin mediationOverview-num body-num6'>220</span>
                      </div>
                    </div>
                  </div>
                </div>
              </Col>
            </Row>
          </Col>
        </Row>
        {/* 这是实时动态 和 类型分布 */}
        <Row className='cardMargin'>
          <Col >
            <div className='mediateBigData-card realTimeData-card'>
              <Col >
                <div className='realTimeData-title' >
                  <div className='red-icon'></div>
                  <span >实时动态</span>
                </div>
                <div className='testBG'>
                  <Table className='realTimeData-table' size='small' pagination={false} columns={realTimeData_tableColumns} dataSource={realTimeData_tableData} scroll={{ y: 176 }} />
                </div>
              </Col>
            </div>
          </Col>
          <Col flex='auto'>
            <div className='mediateBigData-card typeDistribution-card' >
              <div className='typeDistribution-head'>
                <div className='typeDistribution-title' >
                  <div className='red-icon'></div>
                  <span >类型分布</span>
                </div>
                <div className='typeDistribution-RadioPos'>
                  <Radio.Group size="small" className='typeDistribution-radioGroup' value={originOfTypeDistribution} onChange={changeOriginOfTypeDistribution}>
                    <Radio.Button className='typeDistribution-radioItem1' value="机构">机构</Radio.Button>
                    <Radio.Button className='typeDistribution-radioItem2' value="小程序">小程序</Radio.Button>
                    <Radio.Button className='typeDistribution-radioItem3' value="人们调解系统">人民调解系统</Radio.Button>
                    <Radio.Button className='typeDistribution-radioItem4' value="网格">网格</Radio.Button>
                  </Radio.Group>
                </div>
              </div>
              <div className='pie_style'>
                <TypeDistribution_Pie />
                {/* <DonutChart /> */}
                {/* <Pie /> */}
              </div>
            </div>
          </Col>
        </Row>
        {/* 这是趋势分析 */}
        <Row className='cardMargin'>
          <Col className='mediateBigData-card trendAnalysis-card' style={{ width: 770, height: 326, marginRight: 12 }}>
            <div className='trendAnalysis-card'>
              <div className='typeDistribution-head'>
                <div className='trendAnalysis-title' >
                  <div className='red-icon'></div>
                  <span >趋势分析</span>
                </div>
                <div className='typeDistribution-RadioPos'>
                  <Radio.Group size="small" className='typeDistribution-radioGroup' value={originOfTrendAnalysis} onChange={changeOriginOfTrendAnalysis}>
                    <Radio.Button className='typeDistribution-radioItem1' value="收集情况">收集情况</Radio.Button>
                    <Radio.Button className='typeDistribution-radioItem2' value="调解成功率">调解成功率</Radio.Button>
                  </Radio.Group>
                </div>
              </div>
              <div style={{ width: 740, height: 280 }}>
                <MyChart searchChart={searchTotal} roleId={roleId} />
              </div>
            </div>
          </Col>
          {/* 工作排名 */}
          <Col flex='auto'>
            <div className='mediateBigData-card workloadRanking-card'>
              <div className='typeDistribution-head'>
                <div className='workloadRanking-title' >
                  <div className='red-icon'>
                  </div>
                  <span >工作排名</span>
                </div>
                <div className='typeDistribution-RadioPos'>
                  <Radio.Group size="small" className='typeDistribution-radioGroup' value={originOfWorkloadRanking} onChange={changeOriginOfWorkloadRanking} defaultValue={'收案数'}>
                    <Radio.Button className='typeDistribution-radioItem1' value="收案数">收案数</Radio.Button>
                    <Radio.Button className='typeDistribution-radioItem2' value="调解成功数">调解成功数</Radio.Button>
                  </Radio.Group>
                </div>
              </div>
              <div className='workloadRanking-body'>
                <div className='rankingItem'>
                  <div className='item-numFirst item-num'>
                    <div>1</div>
                  </div>
                  <div className='item-name'>
                    <span >同和街调委会</span>
                  </div>
                  <div className='test1'>
                    <RankProgress percent={999 / 1249} color={['l(0) 0:#f85859  1:#fe9f81', '#EDEEF2']} />
                  </div>
                  <div className='item-count'>999</div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-numSecond  item-num'>
                      <div>2</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div >
                      <RankProgress percent={801 / 1249} color={['l(0) 0:#fd8643 0.2:#fd8643 1:#fdc47f', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>801</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-numThird item-num'>
                      <div>3</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={735 / 1249} color={['l(0) 0:#ffb103  1:#ffe09b', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>735</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>4</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={580 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>580</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>5</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>6</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>7</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>
                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>8</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>9</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div >
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>

                <div className='workloadRanking-body'>
                  <div className='rankingItem'>
                    <div className='item-num'>
                      <div>10</div>
                    </div>
                    <div className='item-name'>
                      <span >同和街调委会</span>
                    </div>
                    <div className='test1'>
                      <RankProgress percent={428 / 1249} color={['l(0) 0:#006ed3  1:#48a7ff', '#EDEEF2']} />
                      {/* <ProgressBar progress={80} style={{ width: '200px', height: '18px' }} /> */}
                    </div>
                    <div className='item-count'>428</div>
                  </div>
                </div>
              </div>
            </div>
          </Col>
        </Row>
        {/* 报表统计 */}
        <div div className='mediateBigData-card reportStatistics-card' >
          <div className='reportStatistics-head'>
            <div className='reportStatistics-title' >
              <div className='red-icon'>
              </div>
              <span >报表统计</span>
            </div>
            <div className='reportStatistics-buttonWide'>
              <Button htmlType="submit" className='reportStatistics-button' onClick={() => ExportTable()}>
                导出
              </Button>
            </div>
          </div>
          <div className='reportStatistics-body'>
            <Table className='reportStatistics-table' columns={reportStatisticsColumns} dataSource={reportStatisticsData} onChange={onReportStatisticsChange} size="small" pagination={false} scroll={{ y: 1000 }} />
          </div>

        </div>
      </div>
    </Page>
  );
};

export default MediateBigData;
